Plugin: JS9Info

### JS9 Info Box

Each JS9 window usually has a value/position display in the upper left, which shows the pixel value at the current mouse position, along with position information (WCS and/or image, depending on the current coordinate system.) The Info Box plugin will display this information and more in a separate window.

The information displayed in the Info Box depends on the values contained in the JS9.globalOpts.infoBox property, an array which looks something like this:

        infoBox: ["file", "object", "wcsfov", "wcscen", "wcspos",
                  "impos", "physpos", "value", "regions", "progress"]

The entries listed above tell the Info Box plugin to display the following information:

- file: file name
- object: object name, taken from FITS header
- wcsfov: wcs field of view
- wcscen: wcs center of image
- wcspos: current position in wcs coordinates
- impos: current position in image coordinates
- physpos: current position in physical (file) coordinates
- value: pixel value
- regions: regions, if these are not displayed in a separate window
- progress: progress bar, when used

Currently, the other option(s) for display are:

- dispos: current position in display coordinates

You can change the list of displayed values at run-time using the Preferences plugin or, for site-wide configuration, by changing the value in the js9prefs.js file.